/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package bigsipperformance;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.geom.Ellipse2D;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.CategoryLabelPositions;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.block.BlockBorder;
import org.jfree.chart.labels.ItemLabelAnchor;
import org.jfree.chart.labels.ItemLabelPosition;
import org.jfree.chart.labels.StandardCategoryItemLabelGenerator;
import org.jfree.chart.labels.StandardXYItemLabelGenerator;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.DatasetRenderingOrder;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.category.BarRenderer;
import org.jfree.chart.renderer.category.CategoryItemRenderer;
import org.jfree.chart.renderer.category.LineAndShapeRenderer;
import org.jfree.chart.renderer.xy.StackedXYBarRenderer;
import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.chart.title.LegendTitle;
import org.jfree.data.category.CategoryDataset;
import org.jfree.data.xy.TableXYDataset;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.ui.RectangleEdge;
import org.jfree.ui.TextAnchor;

/**
 *
 * @author big
 */
public class ChartUtility {


    public static JFreeChart createXYBarChart(TableXYDataset dataset) {
        NumberAxis domainAxis = new NumberAxis("Date");
        //domainAxis.setTickMarkPosition(DateTickMarkPosition.MIDDLE);
        domainAxis.setLowerMargin(0.01);
        domainAxis.setUpperMargin(0.01);
        NumberAxis rangeAxis = new NumberAxis("Count");
        rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());
        rangeAxis.setUpperMargin(0.10);  // leave some space for item labels
        StackedXYBarRenderer renderer = new StackedXYBarRenderer(0.15);
        //renderer.setDrawBarOutline(false);
        //renderer.setBaseItemLabelsVisible(true);
        renderer.setBaseItemLabelGenerator(new StandardXYItemLabelGenerator());
        renderer.setBasePositiveItemLabelPosition(new ItemLabelPosition(
                ItemLabelAnchor.OUTSIDE12, TextAnchor.BOTTOM_CENTER));

        //renderer.setBaseToolTipGenerator(new StandardXYToolTipGenerator(
                //"{0} : {1} = {2}", new SimpleDateFormat("yyyy"),
                //new DecimalFormat("0")));

        XYPlot plot = new XYPlot(dataset, domainAxis, rangeAxis, renderer);
        JFreeChart chart = new JFreeChart("Holes-In-One / Double Eagles", plot);
        //chart.removeLegend();
        //chart.addSubtitle(new TextTitle("PGA Tour, 1983 to 2003"));
        //TextTitle source = new TextTitle("http://www.golfdigest.com/majors/masters/index.ssf?/majors/masters/gw20040402albatross.html", new Font("Dialog", Font.PLAIN, 8));
        //chart.addSubtitle(source);
        //chart.setTextAntiAlias(RenderingHints.VALUE_TEXT_ANTIALIAS_DEFAULT);
        LegendTitle legend = new LegendTitle(plot);
        legend.setBackgroundPaint(Color.white);
        legend.setFrame(new BlockBorder());
        legend.setPosition(RectangleEdge.BOTTOM);
        chart.addSubtitle(legend);

        ChartUtilities.applyCurrentTheme(chart);

        return chart;

    }



    public static JFreeChart customize(JFreeChart chart) {
        //renderer.setBaseItemLabelsVisible(true);
        CategoryPlot plot = chart.getCategoryPlot();


        CategoryItemRenderer renderer = plot.getRenderer();
        renderer.setBaseItemLabelsVisible(true);

        plot.setRenderer(renderer);
        //chart = new JFreeChart("", plot);
        ChartUtilities.applyCurrentTheme(chart);
        
        return chart;
    }
    
     public static JFreeChart createCategoryChart(String title, String catAxis, String valAxis, CategoryDataset dataset, PlotOrientation orientation, boolean legend) {
        CategoryAxis categoryAxis = new CategoryAxis(catAxis);
        ValueAxis valueAxis = new NumberAxis(valAxis);

        BarRenderer renderer = new BarRenderer();
        if (orientation == PlotOrientation.HORIZONTAL) {
            ItemLabelPosition position1 = new ItemLabelPosition(
                    ItemLabelAnchor.OUTSIDE3, TextAnchor.CENTER_LEFT);
            renderer.setBasePositiveItemLabelPosition(position1);
            ItemLabelPosition position2 = new ItemLabelPosition(
                    ItemLabelAnchor.OUTSIDE9, TextAnchor.CENTER_RIGHT);
            renderer.setBaseNegativeItemLabelPosition(position2);
         }
        else if (orientation == PlotOrientation.VERTICAL) {
            ItemLabelPosition position1 = new ItemLabelPosition(
                    ItemLabelAnchor.OUTSIDE12, TextAnchor.BOTTOM_CENTER);
            renderer.setBasePositiveItemLabelPosition(position1);
            ItemLabelPosition position2 = new ItemLabelPosition(
                    ItemLabelAnchor.OUTSIDE6, TextAnchor.TOP_CENTER);
            renderer.setBaseNegativeItemLabelPosition(position2);
        }

        categoryAxis.setLowerMargin(0.02);
        categoryAxis.setUpperMargin(0.02);
        categoryAxis.setCategoryLabelPositions(CategoryLabelPositions.UP_90);

        
        renderer.setBaseItemLabelsVisible(true);
        renderer.setBaseItemLabelGenerator(new StandardCategoryItemLabelGenerator());
        renderer.setBasePositiveItemLabelPosition(new ItemLabelPosition(
                ItemLabelAnchor.OUTSIDE12, TextAnchor.BOTTOM_CENTER));
        

        CategoryPlot plot = new CategoryPlot(dataset, categoryAxis, valueAxis, renderer);
        plot.setOrientation(orientation);
        JFreeChart chart = new JFreeChart(title, JFreeChart.DEFAULT_TITLE_FONT,plot, legend);
        ChartUtilities.applyCurrentTheme(chart);
        //currentTheme.apply(chart);
        return chart;
    }

    public static JFreeChart createDualPlotChart(String title, String catAxis, String valAxis1, String valAxis2, CategoryDataset dataset1, CategoryDataset dataset2, PlotOrientation orientation, boolean legend){

        JFreeChart chart = ChartFactory.createStackedBarChart(title, catAxis, valAxis1, dataset1, PlotOrientation.VERTICAL, true, false, false);

        CategoryPlot plot = (CategoryPlot) chart.getPlot();
        CategoryAxis domainAxis = plot.getDomainAxis();
        domainAxis.setLowerMargin(0.02);
        domainAxis.setUpperMargin(0.02);
        domainAxis.setCategoryLabelPositions(CategoryLabelPositions.UP_90);
        // set the range axis to display integers only...
        NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
        rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());

        

        LineAndShapeRenderer renderer = new LineAndShapeRenderer();
        renderer.setBaseShapesVisible(true);
        renderer.setDrawOutlines(true);
        //renderer.setBaseOutlinePaint(Color.BLACK);
        renderer.setUseFillPaint(true);
        renderer.setBaseFillPaint(Color.white);
        renderer.setSeriesShape(0, new Ellipse2D.Double(-5.0, -5.0, 10.0, 10.0));

        NumberAxis axis2 = new NumberAxis(valAxis2);
        //axis2.setNumberFormatOverride(NumberFormat.getIntegerInstance());
        plot.setRangeAxis(1, axis2);
        plot.setDataset(1, dataset2);
        plot.setRenderer(1, renderer);
        plot.mapDatasetToRangeAxis(1, 1);

        plot.setDatasetRenderingOrder(DatasetRenderingOrder.FORWARD);

        ChartUtilities.applyCurrentTheme(chart);
        renderer.setSeriesStroke(0, new BasicStroke(3.0f));
        renderer.setSeriesOutlineStroke(0, new BasicStroke(2.0f));
        renderer.setSeriesPaint(0, Color.DARK_GRAY);


        return chart;

    }


    public static JFreeChart createXYLineChart(String title, String catAxis, String valAxis, XYSeriesCollection dataset1, PlotOrientation orientation, boolean legend){



        JFreeChart chart = ChartFactory.createXYLineChart(title, valAxis, valAxis, dataset1, orientation, legend, false, false);
        XYPlot plot = chart.getXYPlot();
        XYLineAndShapeRenderer renderer = new XYLineAndShapeRenderer();
        renderer.setBaseShapesVisible(false);
        plot.setRenderer(renderer);

        ChartUtilities.applyCurrentTheme(chart);
        for(int i=0;i<dataset1.getSeriesCount();i++)
            renderer.setSeriesStroke(i, new BasicStroke(3.0f));

        return chart;

    }


    

}
